@@ -830,7 +830,6 @@ rasqal_algebra_algebra_node_write_internal(rasqal_algebra_node *node,
     raptor_iostream_string_write("origin ", iostr);
     rasqal_literal_write(node->graph, iostr);
     raptor_iostream_write_byte('\n', iostr);
-    arg_count++;
   }
 
   raptor_iostream_write_byte('\n', iostr);
@@ -932,7 +931,7 @@ rasqal_algebra_basic_graph_pattern_to_algebra(rasqal_query* query,
     rasqal_expression* e;
     e = rasqal_new_expression_from_expression(gp->filter_expression);
     if(!e) {
-      RASQAL_DEBUG1("rasqal_new_expression_from_expression() failed");
+      RASQAL_DEBUG1("rasqal_new_expression_from_expression() failed\n");
       goto fail;
     }
     fs = fs ? rasqal_new_2op_expression(query->world, RASQAL_EXPR_AND, fs, e) : e;
@@ -942,7 +941,7 @@ rasqal_algebra_basic_graph_pattern_to_algebra(rasqal_query* query,
     node = rasqal_new_filter_algebra_node(query, fs, node);
     fs = NULL; /* now owned by node */
     if(!node) {
-      RASQAL_DEBUG1("rasqal_new_filter_algebra_node() failed");
+      RASQAL_DEBUG1("rasqal_new_filter_algebra_node() failed\n");
       goto fail;
     }
   }
@@ -969,14 +968,14 @@ rasqal_algebra_filter_graph_pattern_to_algebra(rasqal_query* query,
 
   e = rasqal_new_expression_from_expression(gp->filter_expression);
   if(!e) {
-    RASQAL_DEBUG1("rasqal_new_expression_from_expression() failed");
+    RASQAL_DEBUG1("rasqal_new_expression_from_expression() failed\n");
     goto fail;
   }
 
   node = rasqal_new_filter_algebra_node(query, e, NULL);
   e = NULL; /* now owned by node */
   if(!node) {
-    RASQAL_DEBUG1("rasqal_new_filter_algebra_node() failed");
+    RASQAL_DEBUG1("rasqal_new_filter_algebra_node() failed\n");
     goto fail;
   }
 
@@ -1009,7 +1008,7 @@ rasqal_algebra_union_graph_pattern_to_algebra(rasqal_query* query,
     
     gnode = rasqal_algebra_graph_pattern_to_algebra(query, sgp);
     if(!gnode) {
-      RASQAL_DEBUG1("rasqal_algebra_graph_pattern_to_algebra() failed");
+      RASQAL_DEBUG1("rasqal_algebra_graph_pattern_to_algebra() failed\n");
       goto fail;
     }
     
@@ -1019,7 +1018,7 @@ rasqal_algebra_union_graph_pattern_to_algebra(rasqal_query* query,
       node = rasqal_new_2op_algebra_node(query, RASQAL_ALGEBRA_OPERATOR_UNION,
                                          node, gnode);
       if(!node) {
-        RASQAL_DEBUG1("rasqal_new_2op_algebra_node() failed");
+        RASQAL_DEBUG1("rasqal_new_2op_algebra_node() failed\n");
         goto fail;
       }
     }
@@ -1050,7 +1049,7 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
 
   gnode = rasqal_new_empty_algebra_node(query);
   if(!gnode) {
-    RASQAL_DEBUG1("rasqal_new_empty_algebra_node() failed");
+    RASQAL_DEBUG1("rasqal_new_empty_algebra_node() failed\n");
     goto fail;
   }
 
@@ -1070,7 +1069,7 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
       /* add all gp->conditions_sequence to FS */
       e = rasqal_new_expression_from_expression(egp->filter_expression);
       if(!e) {
-        RASQAL_DEBUG1("rasqal_new_expression_from_expression() failed");
+        RASQAL_DEBUG1("rasqal_new_expression_from_expression() failed\n");
         goto fail;
       }
       fs = fs ? rasqal_new_2op_expression(query->world, RASQAL_EXPR_AND, fs, e) : e;
@@ -1094,7 +1093,7 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
         /* Let A := Transform(P) */
         anode = rasqal_algebra_graph_pattern_to_algebra(query, sgp);
         if(!anode) {
-          RASQAL_DEBUG1("rasqal_algebra_graph_pattern_to_algebra() failed");
+          RASQAL_DEBUG1("rasqal_algebra_graph_pattern_to_algebra() failed\n");
           goto fail;
         }
         
@@ -1110,7 +1109,7 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
           anode->node1 = NULL;
           rasqal_free_algebra_node(anode);
           if(!gnode) {
-            RASQAL_DEBUG1("rasqal_new_leftjoin_algebra_node() failed");
+            RASQAL_DEBUG1("rasqal_new_leftjoin_algebra_node() failed\n");
             goto fail;
           }
         } else  {
@@ -1119,14 +1118,14 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
 
           true_lit = rasqal_new_boolean_literal(query->world, 1);
           if(!true_lit) {
-            RASQAL_DEBUG1("rasqal_new_boolean_literal() failed");
+            RASQAL_DEBUG1("rasqal_new_boolean_literal() failed\n");
             rasqal_free_algebra_node(anode);
             goto fail;
           }
           
           true_expr = rasqal_new_literal_expression(query->world, true_lit);
           if(!true_expr) {
-            RASQAL_DEBUG1("rasqal_new_literal_expression() failed");
+            RASQAL_DEBUG1("rasqal_new_literal_expression() failed\n");
             rasqal_free_algebra_node(anode);
             goto fail;
           }
@@ -1136,7 +1135,7 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
           gnode = rasqal_new_leftjoin_algebra_node(query, gnode, anode,
                                                    true_expr);
           if(!gnode) {
-            RASQAL_DEBUG1("rasqal_new_leftjoin_algebra_node() failed");
+            RASQAL_DEBUG1("rasqal_new_leftjoin_algebra_node() failed\n");
             goto fail;
           }
 
@@ -1150,7 +1149,7 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
       /* Let A := Transform(E) */
       anode = rasqal_algebra_graph_pattern_to_algebra(query, egp);
       if(!anode) {
-        RASQAL_DEBUG1("rasqal_algebra_graph_pattern_to_algebra() failed");
+        RASQAL_DEBUG1("rasqal_algebra_graph_pattern_to_algebra() failed\n");
         goto fail;
       }
 
@@ -1158,7 +1157,7 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
       gnode = rasqal_new_2op_algebra_node(query, RASQAL_ALGEBRA_OPERATOR_JOIN,
                                           gnode, anode);
       if(!gnode) {
-        RASQAL_DEBUG1("rasqal_new_2op_algebra_node() failed");
+        RASQAL_DEBUG1("rasqal_new_2op_algebra_node() failed\n");
         goto fail;
       }
     }
@@ -1176,7 +1175,7 @@ rasqal_algebra_group_graph_pattern_to_algebra(rasqal_query* query,
     gnode = rasqal_new_filter_algebra_node(query, fs, gnode);
     fs = NULL; /* now owned by gnode */
     if(!gnode) {
-      RASQAL_DEBUG1("rasqal_new_filter_algebra_node() failed");
+      RASQAL_DEBUG1("rasqal_new_filter_algebra_node() failed\n");
       goto fail;
     }
   }
@@ -1212,7 +1211,7 @@ rasqal_algebra_graph_graph_pattern_to_algebra(rasqal_query* query,
   
   gnode = rasqal_algebra_graph_pattern_to_algebra(query, sgp);
   if(!gnode) {
-    RASQAL_DEBUG1("rasqal_algebra_graph_pattern_to_algebra() failed");
+    RASQAL_DEBUG1("rasqal_algebra_graph_pattern_to_algebra() failed\n");
     goto fail;
   }
     
@@ -1430,7 +1429,7 @@ rasqal_algebra_get_variables_mentioned_in(rasqal_query* query,
 {
   raptor_sequence* seq; /* sequence of rasqal_variable* */
   int width;
-  short *row;
+  unsigned short *row;
   int i;
   
   seq = raptor_new_sequence((raptor_data_free_handler)rasqal_free_variable,
@@ -1703,7 +1702,7 @@ rasqal_algebra_query_to_algebra(rasqal_query* query)
                             &modified);
 
 #if RASQAL_DEBUG > 1
-  RASQAL_DEBUG2("modified=%d after remove zones, algebra node now:\n  ", modified);
+  RASQAL_DEBUG1("modified after remove zones, algebra node now:\n  ");
   rasqal_algebra_node_print(node, stderr);
   fputs("\n", stderr);
 #endif
@@ -1775,7 +1774,6 @@ rasqal_algebra_aggregate*
 rasqal_algebra_query_prepare_aggregates(rasqal_query* query,
                                         rasqal_algebra_node* node)
 {
-  int modified = 0;
   rasqal_algebra_aggregate* ae;
   
   ae = (rasqal_algebra_aggregate*)RASQAL_CALLOC(rasqal_algebra_aggregate,
@@ -1784,7 +1782,7 @@ rasqal_algebra_query_prepare_aggregates(rasqal_query* query,
     return NULL;
 
   if(rasqal_algebra_extract_aggregate_expressions(query, node, ae)) {
-    RASQAL_DEBUG1("rasqal_algebra_extract_aggregate_expressions() failed");
+    RASQAL_DEBUG1("rasqal_algebra_extract_aggregate_expressions() failed\n");
     rasqal_free_algebra_aggregate(ae);
     rasqal_free_algebra_node(node);
     return NULL;
@@ -1818,15 +1816,13 @@ rasqal_algebra_query_prepare_aggregates(rasqal_query* query,
     if(rasqal_algebra_replace_aggregate_expressions(query, 
                                                     query->modifier->having_conditions,
                                                     ae)) {
-      RASQAL_DEBUG1("rasqal_algebra_replace_aggregate_expressions() failed");
+      RASQAL_DEBUG1("rasqal_algebra_replace_aggregate_expressions() failed\n");
       rasqal_free_algebra_aggregate(ae);
       rasqal_free_algebra_node(node);
       return NULL;
     }
   }
   
-  modified = 0;
-  
   return ae;
 }
 
@@ -1845,7 +1841,6 @@ rasqal_algebra_query_add_group_by(rasqal_query* query,
                                   rasqal_algebra_node* node)
 {
   raptor_sequence* modifier_seq;
-  int modified;
   
   if(!query->modifier)
     return node;
@@ -1866,11 +1861,9 @@ rasqal_algebra_query_add_group_by(rasqal_query* query,
     }
     
     node = rasqal_new_groupby_algebra_node(query, node, seq);
-    modified = 1;
-    
     
 #if RASQAL_DEBUG > 1
-    RASQAL_DEBUG2("modified=%d after adding group node, algebra node now:\n  ", modified);
+    RASQAL_DEBUG1("modified after adding group node, algebra node now:\n  ");
     rasqal_algebra_node_print(node, stderr);
     fputs("\n", stderr);
 #endif
@@ -1894,7 +1887,6 @@ rasqal_algebra_query_add_modifiers(rasqal_query* query,
                                    rasqal_algebra_node* node)
 {
   raptor_sequence* modifier_seq;
-  int modified;
   
   if(!query->modifier)
     return node;
@@ -1914,10 +1906,9 @@ rasqal_algebra_query_add_modifiers(rasqal_query* query,
     }
     
     node = rasqal_new_orderby_algebra_node(query, node, seq);
-    modified = 1;
     
 #if RASQAL_DEBUG > 1
-    RASQAL_DEBUG2("modified=%d after adding orderby node, algebra node now:\n  ", modified);
+    RASQAL_DEBUG1("modified after adding orderby node, algebra node now:\n  ");
     rasqal_algebra_node_print(node, stderr);
     fputs("\n", stderr);
 #endif
@@ -1944,7 +1935,6 @@ rasqal_algebra_query_add_aggregation(rasqal_query* query,
                                      rasqal_algebra_aggregate* ae,
                                      rasqal_algebra_node* node)
 {
-  int modified = 0;
   raptor_sequence* exprs_seq;
   raptor_sequence* vars_seq;
   
@@ -1965,14 +1955,12 @@ rasqal_algebra_query_add_aggregation(rasqal_query* query,
   node = rasqal_new_aggregation_algebra_node(query, node, exprs_seq, vars_seq);
   exprs_seq = NULL; vars_seq = NULL;
   if(!node) {
-    RASQAL_DEBUG1("rasqal_new_aggregation_algebra_node() failed");
+    RASQAL_DEBUG1("rasqal_new_aggregation_algebra_node() failed\n");
     goto tidy;
   }
   
-  modified = 1;
-  
 #if RASQAL_DEBUG > 1
-  RASQAL_DEBUG2("modified=%d after adding aggregation node, algebra node now:\n  ", modified);
+  RASQAL_DEBUG1("modified after adding aggregation node, algebra node now:\n  ");
   rasqal_algebra_node_print(node, stderr);
   fputs("\n", stderr);
 #endif
@@ -2003,7 +1991,6 @@ rasqal_algebra_node*
 rasqal_algebra_query_add_projection(rasqal_query* query,
                                    rasqal_algebra_node* node)
 {
-  int modified = 0;
   int vars_size = 0;
   raptor_sequence* seq = NULL;  /* sequence of rasqal_variable* */
   raptor_sequence* vars_seq;
@@ -2044,10 +2031,9 @@ rasqal_algebra_query_add_projection(rasqal_query* query,
   }
   
   node = rasqal_new_project_algebra_node(query, node, vars_seq);
-  modified = 1;
   
 #if RASQAL_DEBUG > 1
-  RASQAL_DEBUG2("modified=%d after adding project node, algebra node now:\n  ", modified);
+  RASQAL_DEBUG1("modified after adding project node, algebra node now:\n  ");
   rasqal_algebra_node_print(node, stderr);
   fputs("\n", stderr);
 #endif
@@ -2072,14 +2058,11 @@ rasqal_algebra_node*
 rasqal_algebra_query_add_distinct(rasqal_query* query,
                                   rasqal_algebra_node* node)
 {
-  int modified;
-  
   if(query->distinct) {
     node = rasqal_new_distinct_algebra_node(query, node);
-    modified = 1;
 
 #if RASQAL_DEBUG > 1
-    RASQAL_DEBUG2("modified=%d after adding distinct node, algebra node now:\n  ", modified);
+    RASQAL_DEBUG1("modified after adding distinct node, algebra node now:\n  ");
     rasqal_algebra_node_print(node, stderr);
     fputs("\n", stderr);
 #endif
@@ -2103,7 +2086,6 @@ rasqal_algebra_query_add_having(rasqal_query* query,
                                 rasqal_algebra_node* node)
 {
   raptor_sequence* modifier_seq;
-  int modified;
   
   if(!query->modifier)
     return node;
@@ -2123,10 +2105,9 @@ rasqal_algebra_query_add_having(rasqal_query* query,
     }
     
     node = rasqal_new_having_algebra_node(query, node, exprs_seq);
-    modified = 1;
     
 #if RASQAL_DEBUG > 1
-    RASQAL_DEBUG2("modified=%d after adding having node, algebra node now:\n  ", modified);
+    RASQAL_DEBUG1("modified after adding having node, algebra node now:\n  ");
     rasqal_algebra_node_print(node, stderr);
     fputs("\n", stderr);
 #endif
