@@ -265,6 +265,11 @@ rasqal_expression_evaluate_substr(rasqal_expression *e,
   if(dt_uri)
     dt_uri = raptor_uri_copy(dt_uri);
 
+  rasqal_free_literal(l1);
+  rasqal_free_literal(l2);
+  if(l3)
+    rasqal_free_literal(l3);
+
   /* after this new_s, new_lang and dt_uri become owned by result */
   return rasqal_new_string_literal(world, new_s, new_lang, dt_uri,
                                    /* qname */ NULL);
@@ -355,6 +360,8 @@ rasqal_expression_evaluate_set_case(rasqal_expression *e,
   if(dt_uri)
     dt_uri = raptor_uri_copy(dt_uri);
 
+  rasqal_free_literal(l1);
+
   /* after this new_s, new_lang and dt_uri become owned by result */
   return rasqal_new_string_literal(world, new_s, new_lang, dt_uri,
                                    /* qname */ NULL);
@@ -909,10 +916,9 @@ rasqal_expression_evaluate_strmatch(rasqal_expression *e,
 #endif
 
 #ifdef RASQAL_REGEX_NONE
-  rasqal_log_error_simple(world,
-                          RAPTOR_LOG_LEVEL_WARN,
-                          eval_context->locator,
-                          "Regex support missing, cannot compare '%s' to '%s'", match_string, pattern);
+  rasqal_log_warning_simple(world, RASQAL_WARNING_LEVEL_MISSING_SUPPORT,
+                            eval_context->locator,
+                            "Regex support missing, cannot compare '%s' to '%s'", match_string, pattern);
   b=1;
   rc= -1;
 #endif
