@@ -308,6 +308,7 @@ rasqal_query_results_rdf_write(rasqal_query_results_formatter* formatter,
     statement.object = raptor_new_term_from_literal(raptor_world_ptr, 
                                                     name, NULL, NULL);
     raptor_serializer_serialize_statement(ser, &statement);
+    raptor_free_term(statement.object); statement.object = NULL;
   }
   raptor_free_term(statement.predicate); statement.predicate = NULL;
 
@@ -399,11 +400,16 @@ rasqal_query_results_rdf_write(rasqal_query_results_formatter* formatter,
         raptor_free_term(statement.object); statement.object = NULL;
       }
 
+      raptor_free_term(binding_node);
     }
     
     rasqal_query_results_next(results);
+
+    raptor_free_term(row_node); row_node = NULL;
   }
 
+  raptor_free_term(resultset_node);
+
   raptor_serializer_serialize_end(ser);
 
   raptor_free_serializer(ser);
@@ -574,8 +580,11 @@ rasqal_rowsource_rdf_process(rasqal_rowsource_rdf_context* con)
         v = rasqal_variables_table_add(con->vars_table,
                                        RASQAL_VARIABLE_TYPE_NORMAL,
                                        var_name, NULL);
-        if(v)
+        if(v) {
           rasqal_rowsource_add_variable(con->rowsource, v);
+          /* above function takes a reference to v */
+          rasqal_free_variable(v);
+        }
       }
     }
       
