@@ -665,14 +665,18 @@ rasqal_graph_pattern_write_internal(rasqal_graph_pattern* gp,
 
     raptor_iostream_counted_string_write("select-variables: [", 19, iostr);
     vars_seq = rasqal_projection_get_variables_sequence(gp->projection);
-    for(i = 0; i < raptor_sequence_size(vars_seq); i++) {
-      rasqal_variable* v;
-      v = (rasqal_variable*)raptor_sequence_get_at(vars_seq, i);
+    if(!vars_seq) {
+      raptor_iostream_write_byte('*', iostr);
+    } else {
+      for(i = 0; i < raptor_sequence_size(vars_seq); i++) {
+        rasqal_variable* v;
+        v = (rasqal_variable*)raptor_sequence_get_at(vars_seq, i);
 
-      if(i > 0)
-        raptor_iostream_counted_string_write(", ", 2, iostr);
+        if(i > 0)
+          raptor_iostream_counted_string_write(", ", 2, iostr);
 
-      rasqal_variable_write(v, iostr);
+        rasqal_variable_write(v, iostr);
+      }
     }
     raptor_iostream_counted_string_write("]", 1, iostr);
     
@@ -1062,17 +1066,18 @@ rasqal_graph_pattern_variable_bound_in(rasqal_graph_pattern *gp,
                                        rasqal_variable *v) 
 {
   rasqal_query* query;
-  int column;
+  int width;
+  int gp_offset;
+  unsigned short *row;
   
   RASQAL_ASSERT_OBJECT_POINTER_RETURN_VALUE(gp, rasqal_graph_pattern, 0);
-
-  query = gp->query;
-  column = query->variables_bound_in[v->offset];
-
-  if(column < 0)
-    return 0;
   
-  return (column >= gp->start_column && column <= gp->end_column);
+  query = gp->query;
+  width = rasqal_variables_table_get_total_variables_count(query->vars_table);
+  gp_offset = (gp->gp_index + RASQAL_VAR_USE_MAP_OFFSET_LAST + 1) * width;
+  row = &query->variables_use_map[gp_offset];
+
+  return ((row[v->offset] & RASQAL_VAR_USE_BOUND_HERE) != 0);
 }
 
 
