@@ -327,9 +327,32 @@ typedef enum {
 } rasqal_var_use_map_offset;
 
 
-/* Magic (non-column number) values for query->variables_bound_in */
-#define BOUND_IN_UNBOUND   -1
-#define BOUND_IN_ELSEWHERE -2
+/**
+ * rasqal_triples_use_map_flags:
+ * @RASQAL_TRIPLES_USE_SUBJECT: variable used in subject of this triple
+ * @RASQAL_TRIPLES_USE_PREDICATE: ditto predicate
+ * @RASQAL_TRIPLES_USE_OBJECT: ditto object
+ * @RASQAL_TRIPLES_USE_GRAPH: ditto graph
+ * @RASQAL_TRIPLES_BOUND_SUBJECT: variable bound in subject of this triple
+ * @RASQAL_TRIPLES_BOUND_PREDICATE: ditto predicate
+ * @RASQAL_TRIPLES_BOUND_OBJECT: ditto object
+ * @RASQAL_TRIPLES_BOUND_GRAPH: ditto graph
+ * @RASQAL_TRIPLES_USE_MASK: mask to check if variable is used in any part of TP
+ * @RASQAL_TRIPLES_BOUND_MASK: mask to check if variable is bound in any part of TP (a single variable can be bound at most once in a triple pattern)
+ */
+typedef enum {
+  RASQAL_TRIPLES_USE_SUBJECT     = RASQAL_TRIPLE_SUBJECT,
+  RASQAL_TRIPLES_USE_PREDICATE   = RASQAL_TRIPLE_PREDICATE,
+  RASQAL_TRIPLES_USE_OBJECT      = RASQAL_TRIPLE_OBJECT,
+  RASQAL_TRIPLES_USE_GRAPH       = RASQAL_TRIPLE_GRAPH,
+  RASQAL_TRIPLES_BOUND_SUBJECT   = RASQAL_TRIPLE_SUBJECT   << 4,
+  RASQAL_TRIPLES_BOUND_PREDICATE = RASQAL_TRIPLE_PREDICATE << 4,
+  RASQAL_TRIPLES_BOUND_OBJECT    = RASQAL_TRIPLE_OBJECT    << 4,
+  RASQAL_TRIPLES_BOUND_GRAPH     = RASQAL_TRIPLE_GRAPH     << 4,
+  RASQAL_TRIPLES_USE_MASK        = (RASQAL_TRIPLES_USE_SUBJECT | RASQAL_TRIPLES_USE_PREDICATE | RASQAL_TRIPLES_USE_OBJECT | RASQAL_TRIPLES_USE_GRAPH),
+  RASQAL_TRIPLES_BOUND_MASK      = (RASQAL_TRIPLES_BOUND_SUBJECT | RASQAL_TRIPLES_BOUND_PREDICATE | RASQAL_TRIPLES_BOUND_OBJECT | RASQAL_TRIPLES_BOUND_GRAPH)
+} rasqal_triples_use_map_flags;
+
 
 /*
  * A query in some query language
@@ -389,13 +412,14 @@ struct rasqal_query_s {
    */
   int select_variables_count;
 
-  /* array of size (number of total variables)
-   * pointing to either:
-   *   a) triple column where a variable[offset] is bound (0 or larger)
-   *   b) -1 if not bound anywhere (BOUND_IN_UNBOUND)
-   *   c) -2 if bound outside a triple (e.g. GRAPH, LET ) (BOUND_IN_ELSEWHERE)
+  /* INTERNAL 2D array of:
+   *   width (number of total variables)
+   *   height (number of triples)
+   * marking how a variable is mentioned/used in a TRIPLE PATTERN
+   * Each triple pattern has a row and the short values are per-variable
+   * with flags from #rasqal_triples_use_map_flags
    */
-  int* variables_bound_in;
+  unsigned short* triples_use_map;
 
   /* can be filled with error location information */
   raptor_locator locator;
@@ -473,7 +497,7 @@ struct rasqal_query_s {
    *   2  RASQAL_USE_MENTIONED_HERE
    *   4  RASQAL_USE_BOUND_HERE
    */
-  short* variables_use_map;
+  unsigned short* variables_use_map;
 
   /* sequence of #rasqal_update_operation when @verb is
    * INSERT (deprecated), DELETE (deprecated) or UPDATE
@@ -976,12 +1000,39 @@ unsigned char* rasqal_world_generate_bnodeid(rasqal_world* world, unsigned char
 int rasqal_world_reset_now(rasqal_world* world);
 struct timeval* rasqal_world_get_now_timeval(rasqal_world* world);
 
+
+typedef enum {
+  /* Warnings in 0..100 range.  Warn if LEVEL < world->warning_level */
+  RASQAL_WARNING_LEVEL_MAYBE_ERROR  = 10,
+  RASQAL_WARNING_LEVEL_STYLE        = 30,
+  RASQAL_WARNING_LEVEL_STRICT_STYLE = 90,
+
+  /* Default warning level */
+  RASQAL_WARNING_LEVEL_DEFAULT      = 50,
+  RASQAL_WARNING_LEVEL_MAX          = 100,
+
+  /* Warnings level in code base */
+  RASQAL_WARNING_LEVEL_DUPLICATE_VARIABLE = RASQAL_WARNING_LEVEL_STYLE,
+  RASQAL_WARNING_LEVEL_VARIABLE_UNUSED    = RASQAL_WARNING_LEVEL_STYLE,
+  RASQAL_WARNING_LEVEL_MULTIPLE_BG_GRAPHS = RASQAL_WARNING_LEVEL_STYLE,
+  RASQAL_WARNING_LEVEL_QUERY_SYNTAX       = RASQAL_WARNING_LEVEL_STYLE,
+
+  RASQAL_WARNING_LEVEL_NOT_IMPLEMENTED      = RASQAL_WARNING_LEVEL_MAYBE_ERROR,
+  RASQAL_WARNING_LEVEL_MISSING_SUPPORT      = RASQAL_WARNING_LEVEL_MAYBE_ERROR,
+  RASQAL_WARNING_LEVEL_BAD_TRIPLE           = RASQAL_WARNING_LEVEL_MAYBE_ERROR,
+  RASQAL_WARNING_LEVEL_SELECTED_NEVER_BOUND = RASQAL_WARNING_LEVEL_MAYBE_ERROR,
+
+  RASQAL_WARNING_LEVEL_UNUSED_SELECTED_VARIABLE = RASQAL_WARNING_LEVEL_STRICT_STYLE,
+} rasqal_warning_level;
+
+
 rasqal_query_language_factory* rasqal_query_language_register_factory(rasqal_world *world, int (*factory) (rasqal_query_language_factory*));
 rasqal_query_language_factory* rasqal_get_query_language_factory (rasqal_world*, const char* name, const unsigned char* uri);
 void rasqal_log_error_simple(rasqal_world* world, raptor_log_level level, raptor_locator* locator, const char* message, ...) RASQAL_PRINTF_FORMAT(4, 5);
 void rasqal_log_error_varargs(rasqal_world* world, raptor_log_level level, raptor_locator* locator, const char* message, va_list arguments) RASQAL_PRINTF_FORMAT(4, 0);
 void rasqal_query_simple_error(void* user_data /* query */, const char *message, ...) RASQAL_PRINTF_FORMAT(2, 3);
 void rasqal_world_simple_error(void* user_data /* world */, const char *message, ...) RASQAL_PRINTF_FORMAT(2, 3);
+void rasqal_log_warning_simple(rasqal_world* world, rasqal_warning_level warn_level, raptor_locator* locator, const char* message, ...) RASQAL_PRINTF_FORMAT(4, 5);
 
 const char* rasqal_basename(const char* name);
 unsigned char* rasqal_world_default_generate_bnodeid_handler(void *user_data, unsigned char *user_bnodeid);
@@ -1025,7 +1076,6 @@ int rasqal_query_prepare_common(rasqal_query *query);
 int rasqal_query_merge_graph_patterns(rasqal_query* query, rasqal_graph_pattern* gp, void* data);
 int rasqal_graph_patterns_join(rasqal_graph_pattern *dest_gp, rasqal_graph_pattern *src_gp);
 int rasqal_graph_pattern_move_constraints(rasqal_graph_pattern* dest_gp, rasqal_graph_pattern* src_gp);
-int* rasqal_query_triples_build_bound_in(rasqal_query* query, int size, int start_column, int end_column);
 
 /* rasqal_expr.c */
 rasqal_literal* rasqal_new_string_literal_node(rasqal_world*, const unsigned char *string, const char *language, raptor_uri *datatype);
@@ -1073,6 +1123,7 @@ rasqal_literal* rasqal_expression_evaluate_round(rasqal_expression *e, rasqal_ev
 rasqal_literal* rasqal_expression_evaluate_ceil(rasqal_expression *e, rasqal_evaluation_context *eval_context, int *error_p);
 rasqal_literal* rasqal_expression_evaluate_floor(rasqal_expression *e, rasqal_evaluation_context *eval_context, int *error_p);
 rasqal_literal* rasqal_expression_evaluate_rand(rasqal_expression *e, rasqal_evaluation_context *eval_context, int *error_p);
+rasqal_literal* rasqal_expression_evaluate_digest(rasqal_expression *e, rasqal_evaluation_context *eval_context, int *error_p);
 
 /* rasqal_expr_strings.c */
 rasqal_literal* rasqal_expression_evaluate_substr(rasqal_expression *e, rasqal_evaluation_context *eval_context, int *error_p);
@@ -1099,6 +1150,13 @@ int rasqal_strncasecmp(const char* s1, const char* s2, size_t n);
 #  endif
 #endif
 
+/* timegm.c */
+#ifdef HAVE_TIMEGM
+#define rasqal_timegm timegm
+#else
+time_t rasqal_timegm(struct tm *tm);
+#endif
+
 /* rasqal_raptor.c */
 int rasqal_raptor_init(rasqal_world*);
 
@@ -1180,8 +1238,8 @@ unsigned char* rasqal_query_get_genid(rasqal_query* query, const unsigned char*
 void rasqal_query_set_base_uri(rasqal_query* rq, raptor_uri* base_uri);
 rasqal_variable* rasqal_query_get_variable_by_offset(rasqal_query* query, int idx);
 const rasqal_query_execution_factory* rasqal_query_get_engine_by_name(const char* name);
-int rasqal_query_variable_bound_in_triple(rasqal_query *query, rasqal_variable *v, int column);
-int rasqal_query_get_bound_in_column_for_variable(rasqal_query* query, rasqal_variable* v);
+int rasqal_query_variable_is_bound(rasqal_query* query, rasqal_variable* v);
+rasqal_triple_parts rasqal_query_variable_bound_in_triple(rasqal_query* query, rasqal_variable* v, int column);
 
 /* rasqal_query_results.c */
 int rasqal_init_query_results(void);
@@ -1323,6 +1381,8 @@ struct rasqal_world_s {
   struct timeval now;
   /* set when now is a cached value */
   unsigned int now_set : 1;
+
+  rasqal_warning_level warning_level;
 };
 
 
@@ -1526,10 +1586,6 @@ typedef enum {
 } rasqal_engine_error;
 
 
-#ifdef RASQAL_DEBUG
-const char* rasqal_engine_error_as_string(rasqal_engine_error error);
-#endif
-
 /*
  * A query execution engine factory
  *
@@ -1586,9 +1642,11 @@ struct rasqal_query_execution_factory_s {
 
 
 /* rasqal_engine.c */
+#ifdef RASQAL_DEBUG
+const char* rasqal_engine_get_parts_string(rasqal_triple_parts parts);
+const char* rasqal_engine_error_as_string(rasqal_engine_error error);
+#endif
 
-/* Original Rasqal 0.9.16 query engine executing over graph patterns */
-extern const rasqal_query_execution_factory rasqal_query_engine_1;
 
 /* rasqal_engine_sort.c */
 rasqal_map* rasqal_engine_new_rowsort_map(int is_distinct, int compare_flags, raptor_sequence* order_conditions_sequence);
@@ -1596,9 +1654,6 @@ int rasqal_engine_rowsort_map_add_row(rasqal_map* map, rasqal_row* row);
 raptor_sequence* rasqal_engine_rowsort_map_to_sequence(rasqal_map* map, raptor_sequence* seq);
 int rasqal_engine_rowsort_calculate_order_values(rasqal_query* query, rasqal_row* row);
 
-#ifdef RASQAL_DEBUG
-const char* rasqal_engine_get_parts_string(rasqal_triple_parts parts);
-#endif
 
 /* rasqal_engine_algebra.c */
 
@@ -1638,6 +1693,40 @@ int rasqal_triples_sequence_set_origin(raptor_sequence* dest_seq, raptor_sequenc
 /* rasqal_random.c */
 unsigned int rasqal_random_get_system_seed(rasqal_world* world);
 
+/*
+ * rasqal_digest_type:
+ * RASQAL_DIGEST_NONE: No digest
+ * RASQAL_DIGEST_MD5: MD5
+ * RASQAL_DIGEST_SHA1: SHA1
+ * RASQAL_DIGEST_SHA224: SHA224
+ * RASQAL_DIGEST_SHA256: SHA256
+ * RASQAL_DIGEST_SHA384: SHA384
+ * RASQAL_DIGEST_SHA512: SHA512
+ * RASQAL_DIGEST_LAST: Internal
+ *
+ * INTERNAL - Message digest algorithm for rasqal_digest_buffer()
+*/
+typedef enum {
+  RASQAL_DIGEST_NONE,
+  RASQAL_DIGEST_MD5,
+  RASQAL_DIGEST_SHA1,
+  RASQAL_DIGEST_SHA224,
+  RASQAL_DIGEST_SHA256,
+  RASQAL_DIGEST_SHA384,
+  RASQAL_DIGEST_SHA512,
+  RASQAL_DIGEST_LAST = RASQAL_DIGEST_SHA512
+} rasqal_digest_type;
+
+int rasqal_digest_buffer(rasqal_digest_type type, const unsigned char *output, const unsigned char * const input, size_t len);
+#ifdef RASQAL_DIGEST_INTERNAL
+
+int rasqal_digest_sha1_buffer(const unsigned char *output,
+                              const unsigned char *input, size_t len);
+int rasqal_digest_md5_buffer(const unsigned char *output,
+                             const unsigned char *input, size_t len);
+#endif
+
+
 /* end of RASQAL_INTERNAL */
 #endif
 
