@@ -105,22 +105,24 @@ rasqal_join_rowsource_init(rasqal_rowsource* rowsource, void *user_data)
     rasqal_query *query = rowsource->query;
     rasqal_literal* result;
     int bresult;
+    int error = 0;
     
-    result = rasqal_expression_evaluate(rowsource->world, &query->locator,
-                                        con->expr, query->compare_flags);
+    result = rasqal_expression_evaluate2(con->expr, query->eval_context,
+                                         &error);
 
 #ifdef RASQAL_DEBUG
     RASQAL_DEBUG1("join expression condition is constant: ");
-    if(!result)
+    if(error)
       fputs("type error", DEBUG_FH);
     else
       rasqal_literal_print(result, DEBUG_FH);
     fputc('\n', DEBUG_FH);
 #endif
-    if(!result) {
+
+    if(error) {
       bresult = 0;
     } else {
-      int error = 0;
+      error = 0;
       bresult = rasqal_literal_as_boolean(result, &error);
 #ifdef RASQAL_DEBUG
       if(error)
@@ -368,21 +370,23 @@ rasqal_join_rowsource_read_row(rasqal_rowsource* rowsource, void *user_data)
     /* Check join expression if present */
     if(con->expr) {
       rasqal_literal *result;
-
-      result = rasqal_expression_evaluate(rowsource->world, &query->locator,
-                                          con->expr, query->compare_flags);
+      int error = 0;
+      
+      result = rasqal_expression_evaluate2(con->expr, query->eval_context,
+                                           &error);
 #ifdef RASQAL_DEBUG
       RASQAL_DEBUG1("join expression result: ");
-      if(!result)
+      if(error)
         fputs("type error", DEBUG_FH);
       else
         rasqal_literal_print(result, DEBUG_FH);
       fputc('\n', DEBUG_FH);
 #endif
-      if(!result) {
+
+      if(error) {
         bresult = 0;
       } else {
-        int error = 0;
+        error = 0;
         bresult = rasqal_literal_as_boolean(result, &error);
 #ifdef RASQAL_DEBUG
         if(error)
@@ -533,10 +537,10 @@ static const rasqal_rowsource_handler rasqal_join_rowsource_handler = {
 
 /**
  * rasqal_new_join_rowsource:
- * @world: query world
- * @query: query results object
- * @left: left (first) rowsource
- * @right: right (second) rowsource
+ * @world: world object
+ * @query: query object
+ * @left: input left (first) rowsource
+ * @right: input right (second) rowsource
  * @join_type: join type
  * @expr: join expression to filter result rows
  *
@@ -547,6 +551,8 @@ static const rasqal_rowsource_handler rasqal_join_rowsource_handler = {
  * sequence are the same.  If not, construction fails and NULL is
  * returned.
  *
+ * The @left and @right rowsources become owned by the rowsource.
+ *
  * Return value: new rowsource or NULL on failure
  */
 rasqal_rowsource*
