@@ -135,40 +135,46 @@
      CEIL = 351,
      FLOOR = 352,
      RAND = 353,
-     EXPLAIN = 354,
-     LET = 355,
-     CURRENT_DATETIME = 356,
-     NOW = 357,
-     FROM_UNIXTIME = 358,
-     TO_UNIXTIME = 359,
-     HATHAT = 360,
-     SC_OR = 361,
-     SC_AND = 362,
-     EQ = 363,
-     NEQ = 364,
-     LT = 365,
-     GT = 366,
-     LE = 367,
-     GE = 368,
-     ASSIGN = 369,
-     STRING = 370,
-     LANG_TAG = 371,
-     DOUBLE_LITERAL = 372,
-     DOUBLE_POSITIVE_LITERAL = 373,
-     DOUBLE_NEGATIVE_LITERAL = 374,
-     INTEGER_LITERAL = 375,
-     INTEGER_POSITIVE_LITERAL = 376,
-     INTEGER_NEGATIVE_LITERAL = 377,
-     DECIMAL_LITERAL = 378,
-     DECIMAL_POSITIVE_LITERAL = 379,
-     DECIMAL_NEGATIVE_LITERAL = 380,
-     BOOLEAN_LITERAL = 381,
-     URI_LITERAL = 382,
-     URI_LITERAL_BRACE = 383,
-     QNAME_LITERAL = 384,
-     QNAME_LITERAL_BRACE = 385,
-     BLANK_LITERAL = 386,
-     IDENTIFIER = 387
+     MD5 = 354,
+     SHA1 = 355,
+     SHA224 = 356,
+     SHA256 = 357,
+     SHA384 = 358,
+     SHA512 = 359,
+     EXPLAIN = 360,
+     LET = 361,
+     CURRENT_DATETIME = 362,
+     NOW = 363,
+     FROM_UNIXTIME = 364,
+     TO_UNIXTIME = 365,
+     HATHAT = 366,
+     SC_OR = 367,
+     SC_AND = 368,
+     EQ = 369,
+     NEQ = 370,
+     LT = 371,
+     GT = 372,
+     LE = 373,
+     GE = 374,
+     ASSIGN = 375,
+     STRING = 376,
+     LANG_TAG = 377,
+     DOUBLE_LITERAL = 378,
+     DOUBLE_POSITIVE_LITERAL = 379,
+     DOUBLE_NEGATIVE_LITERAL = 380,
+     INTEGER_LITERAL = 381,
+     INTEGER_POSITIVE_LITERAL = 382,
+     INTEGER_NEGATIVE_LITERAL = 383,
+     DECIMAL_LITERAL = 384,
+     DECIMAL_POSITIVE_LITERAL = 385,
+     DECIMAL_NEGATIVE_LITERAL = 386,
+     BOOLEAN_LITERAL = 387,
+     URI_LITERAL = 388,
+     URI_LITERAL_BRACE = 389,
+     QNAME_LITERAL = 390,
+     QNAME_LITERAL_BRACE = 391,
+     BLANK_LITERAL = 392,
+     IDENTIFIER = 393
    };
 #endif
 /* Tokens.  */
@@ -268,40 +274,46 @@
 #define CEIL 351
 #define FLOOR 352
 #define RAND 353
-#define EXPLAIN 354
-#define LET 355
-#define CURRENT_DATETIME 356
-#define NOW 357
-#define FROM_UNIXTIME 358
-#define TO_UNIXTIME 359
-#define HATHAT 360
-#define SC_OR 361
-#define SC_AND 362
-#define EQ 363
-#define NEQ 364
-#define LT 365
-#define GT 366
-#define LE 367
-#define GE 368
-#define ASSIGN 369
-#define STRING 370
-#define LANG_TAG 371
-#define DOUBLE_LITERAL 372
-#define DOUBLE_POSITIVE_LITERAL 373
-#define DOUBLE_NEGATIVE_LITERAL 374
-#define INTEGER_LITERAL 375
-#define INTEGER_POSITIVE_LITERAL 376
-#define INTEGER_NEGATIVE_LITERAL 377
-#define DECIMAL_LITERAL 378
-#define DECIMAL_POSITIVE_LITERAL 379
-#define DECIMAL_NEGATIVE_LITERAL 380
-#define BOOLEAN_LITERAL 381
-#define URI_LITERAL 382
-#define URI_LITERAL_BRACE 383
-#define QNAME_LITERAL 384
-#define QNAME_LITERAL_BRACE 385
-#define BLANK_LITERAL 386
-#define IDENTIFIER 387
+#define MD5 354
+#define SHA1 355
+#define SHA224 356
+#define SHA256 357
+#define SHA384 358
+#define SHA512 359
+#define EXPLAIN 360
+#define LET 361
+#define CURRENT_DATETIME 362
+#define NOW 363
+#define FROM_UNIXTIME 364
+#define TO_UNIXTIME 365
+#define HATHAT 366
+#define SC_OR 367
+#define SC_AND 368
+#define EQ 369
+#define NEQ 370
+#define LT 371
+#define GT 372
+#define LE 373
+#define GE 374
+#define ASSIGN 375
+#define STRING 376
+#define LANG_TAG 377
+#define DOUBLE_LITERAL 378
+#define DOUBLE_POSITIVE_LITERAL 379
+#define DOUBLE_NEGATIVE_LITERAL 380
+#define INTEGER_LITERAL 381
+#define INTEGER_POSITIVE_LITERAL 382
+#define INTEGER_NEGATIVE_LITERAL 383
+#define DECIMAL_LITERAL 384
+#define DECIMAL_POSITIVE_LITERAL 385
+#define DECIMAL_NEGATIVE_LITERAL 386
+#define BOOLEAN_LITERAL 387
+#define URI_LITERAL 388
+#define URI_LITERAL_BRACE 389
+#define QNAME_LITERAL 390
+#define QNAME_LITERAL_BRACE 391
+#define BLANK_LITERAL 392
+#define IDENTIFIER 393
 
 
 
@@ -337,7 +349,7 @@ typedef union YYSTYPE
 
 
 /* Line 1676 of yacc.c  */
-#line 341 "sparql_parser.tab.h"
+#line 353 "sparql_parser.tab.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
