@@ -86,9 +86,9 @@ static char *program=NULL;
 
 #ifdef RASQAL_INTERNAL
 /* add 'g:' */
-#define GETOPT_STRING "cd:D:e:f:F:g:G:hi:np:r:qs:v"
+#define GETOPT_STRING "cd:D:e:Ef:F:g:G:hi:np:r:qs:vW:"
 #else
-#define GETOPT_STRING "cd:D:e:f:F:G:hi:np:r:qs:v"
+#define GETOPT_STRING "cd:D:e:Ef:F:G:hi:np:r:qs:vW:"
 #endif
 
 #ifdef HAVE_GETOPT_LONG
@@ -104,11 +104,9 @@ static struct option long_options[] =
   {"dump-query", 1, 0, 'd'},
   {"data", 1, 0, 'D'},
   {"exec", 1, 0, 'e'},
+  {"ignore-errors", 0, 0, 'E'},
   {"feature", 1, 0, 'f'},
   {"format", 1, 0, 'F'},
-#ifdef RASQAL_INTERNAL
-  {"engine", 1, 0, 'g'},
-#endif
   {"named", 1, 0, 'G'},
   {"help", 0, 0, 'h'},
   {"input", 1, 0, 'i'},
@@ -118,6 +116,7 @@ static struct option long_options[] =
   {"results", 1, 0, 'r'},
   {"source", 1, 0, 's'},
   {"version", 0, 0, 'v'},
+  {"warnings", 1, 0, 'W'},
 #ifdef STORE_RESULTS_FLAG
   {"store-results", 1, 0, STORE_RESULTS_FLAG},
 #endif
@@ -127,6 +126,10 @@ static struct option long_options[] =
 
 
 static int error_count = 0;
+static int warning_count = 0;
+
+static int warning_level = -1;
+static int ignore_errors = 0;
 
 static const char *title_format_string = "Rasqal RDF query utility %s\n";
 
@@ -140,17 +143,42 @@ static const char *title_format_string = "Rasqal RDF query utility %s\n";
 
 
 static void
-roqet_log_handler(void* user_data, raptor_log_message *message)
+roqet_log_handler(void *data, raptor_log_message *message)
 {
-  /* Only interested in errors and more severe */
-  if(message->level < RAPTOR_LOG_LEVEL_ERROR)
-    return;
+  switch(message->level) {
+    case RAPTOR_LOG_LEVEL_FATAL:
+    case RAPTOR_LOG_LEVEL_ERROR:
+      if(!ignore_errors) {
+        fprintf(stderr, "%s: Error - ", program);
+        raptor_locator_print(message->locator, stderr);
+        fprintf(stderr, " - %s\n", message->text);
+      }
 
-  fprintf(stderr, "%s: Error - ", program);
-  raptor_locator_print(message->locator, stderr);
-  fprintf(stderr, " - %s\n", message->text);
+      error_count++;
+      break;
+
+    case RAPTOR_LOG_LEVEL_WARN:
+      if(warning_level > 0) {
+        fprintf(stderr, "%s: Warning - ", program);
+        raptor_locator_print(message->locator, stderr);
+        fprintf(stderr, " - %s\n", message->text);
+      }
+
+      warning_count++;
+      break;
+
+    case RAPTOR_LOG_LEVEL_NONE:
+    case RAPTOR_LOG_LEVEL_TRACE:
+    case RAPTOR_LOG_LEVEL_DEBUG:
+    case RAPTOR_LOG_LEVEL_INFO:
+
+      fprintf(stderr, "%s: Unexpected %s message - ", program,
+              raptor_log_level_get_label(message->level));
+      raptor_locator_print(message->locator, stderr);
+      fprintf(stderr, " - %s\n", message->text);
+      break;
+  }
 
-  error_count++;
 }
 
 #define SPACES_LENGTH 80
@@ -760,7 +788,6 @@ main(int argc, char *argv[])
   raptor_world* raptor_world_ptr = NULL;
 #ifdef RASQAL_INTERNAL
   int store_results = -1;
-  const rasqal_query_execution_factory* engine = NULL;
 #endif
   char* data_graph_parser_name = NULL;
   raptor_iostream* iostr = NULL;
@@ -1069,6 +1096,18 @@ main(int argc, char *argv[])
         }
         break;
 
+      case 'W':
+        if(optarg)
+          warning_level = atoi(optarg);
+        else
+          warning_level = 0;
+        rasqal_world_set_warning_level(world, warning_level);
+        break;
+
+      case 'E':
+        ignore_errors = 1;
+        break;
+
       case 'v':
         fputs(rasqal_version_string, stdout);
         fputc('\n', stdout);
@@ -1081,12 +1120,6 @@ main(int argc, char *argv[])
         break;
 #endif
 
-#ifdef RASQAL_INTERNAL
-      case 'g':
-        engine = rasqal_query_get_engine_by_name(optarg);
-        break;
-#endif
-
     }
     
   }
@@ -1189,23 +1222,22 @@ main(int argc, char *argv[])
     }
     puts("\nAdditional options:");
     puts(HELP_TEXT("c", "count             ", "Count triples - no output"));
-    puts(HELP_TEXT("d", "dump-query FORMAT ", "Print the parsed query out in FORMAT:"));
-    puts(HELP_TEXT("D", "data URI          ", "RDF data source URI"));
+    puts(HELP_TEXT("d FORMAT", "dump-query FORMAT", HELP_PAD "Print the parsed query out in FORMAT:"));
+    puts(HELP_TEXT("D URI", "data URI      ", "RDF data source URI"));
     for(i = 1; i <= QUERY_OUTPUT_LAST; i++)
       printf("      %-15s         %s\n", query_output_format_labels[i][0],
              query_output_format_labels[i][1]);
+    puts(HELP_TEXT("E", "ignore-errors     ", "Ignore error messages"));
     puts(HELP_TEXT("f FEATURE(=VALUE)", "feature FEATURE(=VALUE)", HELP_PAD "Set query features" HELP_PAD "Use `-f help' for a list of valid features"));
-    puts(HELP_TEXT("F", "format NAME       ", "Set data source format name (default: guess)"));
-#ifdef RASQAL_INTERNAL
-    puts(HELP_TEXT("g", "engine NAME       ", "INTERNAL: Pick execution engine NAME"));
-#endif
-    puts(HELP_TEXT("G", "named URI         ", "RDF named graph data source URI"));
+    puts(HELP_TEXT("F NAME", "format NAME  ", "Set data source format name (default: guess)"));
+    puts(HELP_TEXT("G URI", "named URI     ", "RDF named graph data source URI"));
     puts(HELP_TEXT("h", "help              ", "Print this help, then exit"));
     puts(HELP_TEXT("n", "dryrun            ", "Prepare but do not run the query"));
     puts(HELP_TEXT("q", "quiet             ", "No extra information messages"));
-    puts(HELP_TEXT("s", "source URI        ", "Same as `-G URI'"));
+    puts(HELP_TEXT("s URI", "source URI    ", "Same as `-G URI'"));
     puts(HELP_TEXT("v", "version           ", "Print the Rasqal version"));
     puts(HELP_TEXT("w", "walk-query        ", "Print query.  Same as '-d structure'"));
+    puts(HELP_TEXT("W LEVEL", "warnings LEVEL", HELP_PAD "Set warning message LEVEL from 0: none to 100: all"));
 #ifdef STORE_RESULTS_FLAG
     puts(HELP_TEXT_LONG("store-results BOOL", "DEBUG: Set store results yes/no BOOL"));
 #endif
@@ -1405,11 +1437,7 @@ main(int argc, char *argv[])
       roqet_print_query(rq, raptor_world_ptr, output_format, base_uri);
     
     if(!dryrun) {
-#ifdef RASQAL_INTERNAL
-      results = rasqal_query_execute_with_engine(rq, engine);
-#else
       results = rasqal_query_execute(rq);
-#endif
     }
 
   }
@@ -1475,6 +1503,12 @@ main(int argc, char *argv[])
     raptor_free_uri(service_uri);
 
   rasqal_free_world(world);
+
+  if(error_count && !ignore_errors)
+    return 1;
+
+  if(warning_count && warning_level != 0)
+    return 2;
   
   return (rc);
 }
